@@ -20,6 +20,7 @@ use crev_data::{
     },
     Digest, Id, Version,
 };
+use crev_wot::PkgVersionReviewId;
 pub use crev_wot::TrustDistanceParams;
 use std::{
     collections::{HashMap, HashSet},
@@ -250,11 +251,23 @@ pub fn verify_package_digest(
 ) -> VerificationStatus {
     let reviews: HashMap<Id, review::Package> = db
         .get_package_reviews_by_digest(digest)
+        .filter(|review| {
+            match trust_set
+                .package_review_ignore_override
+                .get(&PkgVersionReviewId::from(review))
+            {
+                Some(reporters) => {
+                    reporters.max_level().unwrap_or(TrustLevel::None)
+                        <= trust_set.get_effective_trust_level(&review.common.from.id)
+                }
+                None => true,
+            }
+        })
         .map(|review| (review.from().id.clone(), review))
         .collect();
     // Faster somehow maybe?
     let reviews_by: HashSet<Id, _> = reviews.keys().cloned().collect();
-    let trusted_ids: HashSet<_> = trust_set.trusted_ids().cloned().collect();
+    let trusted_ids: HashSet<_> = trust_set.get_trusted_ids();
     let matching_reviewers = trusted_ids.intersection(&reviews_by);
     let mut trust_count = 0;
     let mut negative_count = 0;
@@ -347,10 +360,7 @@ pub fn dir_verify(
 }
 
 pub fn get_dir_digest(path: &Path, ignore_list: &fnv::FnvHashSet<PathBuf>) -> Result<Digest> {
-    Ok(Digest::from_vec(util::get_recursive_digest_for_dir(
-        path,
-        ignore_list,
-    )?).unwrap())
+    Ok(Digest::from_vec(util::get_recursive_digest_for_dir(path, ignore_list)?).unwrap())
 }
 
 pub fn get_recursive_digest_for_git_dir(
@@ -390,7 +400,8 @@ pub fn get_recursive_digest_for_dir(
     Ok(Digest::from_vec(util::get_recursive_digest_for_dir(
         root_path,
         rel_path_ignore_list,
-    )?).unwrap())
+    )?)
+    .unwrap())
 }
 
 #[cfg(test)]
