@@ -9,7 +9,7 @@ use crev_common::{
 };
 use crev_data::{
     id::UnlockedId,
-    proof::{self, trust::TrustLevel},
+    proof::{self, trust::TrustLevel, OverrideItem},
     Id, PublicId, Url,
 };
 use default::default;
@@ -98,7 +98,8 @@ impl UserConfig {
 ///
 /// This managed IDs, local proof repository, etc.
 pub struct Local {
-    root_path: PathBuf,
+    config_path: PathBuf,
+    data_path: PathBuf,
     cache_path: PathBuf,
     cur_url: Mutex<Option<Url>>,
     user_config: Mutex<Option<UserConfig>>,
@@ -110,11 +111,14 @@ impl Local {
         let proj_dir = match std::env::var_os("CARGO_CREV_ROOT_DIR_OVERRIDE") {
             None => ProjectDirs::from("", "", "crev"),
             Some(path) => ProjectDirs::from_path(path.into()),
-        }.ok_or(Error::NoHomeDirectory)?;
-        let root_path = proj_dir.config_dir().into();
+        }
+        .ok_or(Error::NoHomeDirectory)?;
+        let config_path = proj_dir.config_dir().into();
+        let data_path = proj_dir.data_dir().into();
         let cache_path = proj_dir.cache_dir().into();
         Ok(Self {
-            root_path,
+            config_path,
+            data_path,
             cache_path,
             cur_url: Mutex::new(None),
             user_config: Mutex::new(None),
@@ -122,12 +126,17 @@ impl Local {
     }
 
     /// Where the config is stored
-    pub fn get_root_path(&self) -> &Path {
-        &self.root_path
+    pub fn config_root(&self) -> &Path {
+        &self.config_path
+    }
+
+    /// Where the data is stored
+    pub fn data_root(&self) -> &Path {
+        &self.data_path
     }
 
     /// Where temporary files are stored
-    pub fn get_root_cache_dir(&self) -> &Path {
+    pub fn cache_root(&self) -> &Path {
         &self.cache_path
     }
 
@@ -135,9 +144,17 @@ impl Local {
     pub fn auto_open() -> Result<Self> {
         let repo = Self::new()?;
         fs::create_dir_all(&repo.cache_remotes_path())?;
-        if !repo.root_path.exists() || !repo.user_config_path().exists() {
+        if !repo.config_path.exists() || !repo.user_config_path().exists() {
             return Err(Error::UserConfigNotInitialized);
         }
+        fs::create_dir_all(&repo.data_path)?;
+
+        // Before early 2022, proofs were in the config dir instead of the data dir.
+        let old_proofs = repo.config_path.join("proofs");
+        let new_proofs = repo.data_path.join("proofs");
+        if !new_proofs.exists() && old_proofs.exists() {
+            fs::rename(old_proofs, new_proofs)?;
+        }
 
         *repo.user_config.lock().unwrap() = Some(repo.load_user_config()?);
         Ok(repo)
@@ -146,7 +163,8 @@ impl Local {
     /// Fails if it already exists. See `auto_create_or_open()`
     pub fn auto_create() -> Result<Self> {
         let repo = Self::new()?;
-        fs::create_dir_all(&repo.root_path)?;
+        fs::create_dir_all(&repo.config_path)?;
+        fs::create_dir_all(&repo.data_path)?;
         fs::create_dir_all(&repo.cache_remotes_path())?;
 
         let config_path = repo.user_config_path();
@@ -219,7 +237,7 @@ impl Local {
 
     /// Same as get_root_path()
     pub fn user_dir_path(&self) -> PathBuf {
-        self.root_path.clone()
+        self.config_path.clone()
     }
 
     /// Directory where yaml files for user identities are stored
@@ -231,7 +249,7 @@ impl Local {
     ///
     /// This is separate from cache of other people's proofs
     pub fn user_proofs_path(&self) -> PathBuf {
-        self.root_path.join("proofs")
+        self.data_path.join("proofs")
     }
 
     /// Like `user_proofs_path` but checks if the dir exists
@@ -522,7 +540,11 @@ impl Local {
         }
         if let Err(e) = git2::Repository::init(&proof_dir) {
             warn!("Can't init repo in {}: {}", proof_dir.display(), e);
-            self.run_git(vec!["init".into(), "--initial-branch=master".into(), proof_dir.into()])?;
+            self.run_git(vec![
+                "init".into(),
+                "--initial-branch=master".into(),
+                proof_dir.into(),
+            ])?;
         }
         Ok(())
     }
@@ -582,7 +604,7 @@ impl Local {
 
         self.ensure_proofs_root_exists()?;
 
-        match git2::Repository::clone(git_https_url, &proof_dir) {
+        match util::git::clone(git_https_url, &proof_dir) {
             Ok(repo) => {
                 debug!("{} cloned to {}", git_https_url, proof_dir.display());
                 repo.remote_set_url("origin", &push_url)?;
@@ -720,6 +742,7 @@ impl Local {
         from_id: &PublicId,
         ids: Vec<Id>,
         trust_level: TrustLevel,
+        override_: Vec<OverrideItem>,
     ) -> Result<proof::trust::Trust> {
         if ids.is_empty() {
             return Err(Error::NoIdsGiven);
@@ -747,7 +770,7 @@ impl Local {
             }
         }
 
-        Ok(from_id.create_trust_proof(&public_ids, trust_level)?)
+        Ok(from_id.create_trust_proof(&public_ids, trust_level, override_)?)
     }
 
     /// Fetch other people's proof repostiory from a git URL, into the current database on disk
@@ -757,10 +780,10 @@ impl Local {
     }
 
     /// Fetch other people's proof repostiory from a git URL, directly into the given db (and disk too)
-    pub fn fetch_url_into(&self, url: &str, mut db: &mut crev_wot::ProofDB) -> Result<()> {
+    pub fn fetch_url_into(&self, url: &str, db: &mut crev_wot::ProofDB) -> Result<()> {
         info!("Fetching {}... ", url);
         let dir = self.fetch_remote_git(url)?;
-        self.import_proof_dir_and_print_counts(&dir, url, &mut db)?;
+        self.import_proof_dir_and_print_counts(&dir, url, db)?;
         let mut db = crev_wot::ProofDB::new();
         let url = Url::new_git(url);
         let fetch_source = self.get_fetch_source_for_url(url.clone())?;
@@ -776,7 +799,7 @@ impl Local {
                 }
                 None => "copy from another repo",
             };
-            println!("{:>8} {} ({})", count, id, verified_state);
+            info!("{:>8} {} ({})", count, id, verified_state);
         }
         Ok(())
     }
@@ -813,7 +836,7 @@ impl Local {
         loop {
             let trust_set = db.calculate_trust_set(&for_id, &trust_params);
             if !self.fetch_ids_not_fetched_yet(
-                trust_set.trusted_ids().cloned(),
+                trust_set.iter_trusted_ids().cloned(),
                 &mut already_fetched_ids,
                 &mut already_fetched_urls,
                 &mut db,
@@ -838,7 +861,7 @@ impl Local {
         loop {
             let trust_set = db.calculate_trust_set(&for_id, &trust_params);
             if !self.fetch_ids_not_fetched_yet(
-                trust_set.trusted_ids().cloned(),
+                trust_set.iter_trusted_ids().cloned(),
                 &mut already_fetched_ids,
                 &mut already_fetched_urls,
                 &mut db,
@@ -968,7 +991,7 @@ impl Local {
             let repo = git2::Repository::open(&dir)?;
             util::git::fetch_and_checkout_git_repo(&repo)?
         } else {
-            git2::Repository::clone(url, &dir)?;
+            util::git::clone(url, &dir)?;
         }
 
         Ok(dir)
@@ -1007,7 +1030,7 @@ impl Local {
             (false, false) => "no updates".into(),
         };
 
-        eprintln!("{:<60} {}", url, msg);
+        info!("{:<60} {}", url, msg);
         Ok(())
     }
 
@@ -1017,7 +1040,7 @@ impl Local {
         let mut fetched_urls = HashSet::new();
         let mut db = self.load_db()?;
 
-        eprintln!("Fetching...");
+        info!("Fetching...");
         // Temporarily hardcode `dpc`'s proof-repo url
         let dpc_url = "https://github.com/dpc/crev-proofs";
         if let Ok(dir) = self.fetch_remote_git(dpc_url).map_err(|e| warn!("{}", e)) {
@@ -1142,9 +1165,18 @@ impl Local {
             &[]
         };
 
-        let signature = repo.signature().or_else(|_| git2::Signature::now("unconfigured", "nobody@crev.dev"))?;
+        let signature = repo
+            .signature()
+            .or_else(|_| git2::Signature::now("unconfigured", "nobody@crev.dev"))?;
 
-        repo.commit(Some("HEAD"), &signature, &signature, commit_msg, &tree, parents)?;
+        repo.commit(
+            Some("HEAD"),
+            &signature,
+            &signature,
+            commit_msg,
+            &tree,
+            parents,
+        )?;
 
         Ok(())
     }
