@@ -244,8 +244,11 @@ fn escape_tricky_unicode_str(input: &str) -> Cow<str> {
     for ch in input.chars() {
         match ch {
             // https://blog.rust-lang.org/2021/11/01/cve-2021-42574.html
-            '\u{202A}' | '\u{202B}' | '\u{202C}' | '\u{202D}' | '\u{202E}' | '\u{2066}'
-            | '\u{2067}' | '\u{2068}' | '\u{2069}' => {
+            // https://www.unicode.org/L2/L2022/22007r2-avoiding-spoof.pdf
+            '\u{115F}' | '\u{1160}' | '\u{13437}' | '\u{13438}' | '\u{1D173}' | '\u{1D174}' | '\u{1D175}' | '\u{1D176}' | '\u{1D177}' |
+            '\u{1D178}' | '\u{1D179}' | '\u{1D17A}' | '\u{202A}' | '\u{202B}' | '\u{202C}' | '\u{202D}' | '\u{202E}' | '\u{2066}' |
+            '\u{2067}' | '\u{2068}' | '\u{2069}' | '\u{206A}' | '\u{206B}' | '\u{206C}' | '\u{206D}' | '\u{206E}' | '\u{206F}' |
+            '\u{3164}' | '\u{FFA0}' | '\u{FFF9}' | '\u{FFFA}' | '\u{FFFB}' => {
                 let _ = write!(&mut out, "\\u{{{:04x}}}", ch as u32);
             }
             _ => out.push(ch),
